@@ -43,12 +43,15 @@ class InputHandler(object):
         if _input in self.handlers:
             self.handlers[_input](_input)
             return True
+        
         try:
-            if curses.ascii.unctrl(_input) in self.handlers:
-                self.handlers[curses.ascii.unctrl(_input)](_input)
-                return True
+            _unctrl_input = curses.ascii.unctrl(_input)
         except TypeError:
-            pass
+            _unctrl_input = None
+        
+        if _unctrl_input and (_unctrl_input in self.handlers):
+            self.handlers[_unctrl_input](_input)
+            return True
 
 
         if not hasattr(self, 'complex_handlers'): 
